@@ -6,9 +6,29 @@ use Mojo::JSON;
 use Mojo::Util 'deprecated';
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '1.19';
+our $VERSION = '1.20';
 my $X_RE = qr{^x-};
 
+has _default_response => sub {
+  return {
+    description => "Default response.",
+    schema      => {
+      type       => "object",
+      required   => ["errors"],
+      properties => {
+        errors => {
+          type  => "array",
+          items => {
+            type       => "object",
+            required   => ["message", "path"],
+            properties => {message => {"type" => "string"}, path => {"type" => "string"}}
+          }
+        }
+      }
+    }
+  };
+};
+
 has _security_cb => undef;
 has _validator => sub { JSON::Validator::OpenAPI::Mojolicious->new; };
 
@@ -35,6 +55,8 @@ sub register {
     push @{$app->renderer->classes}, __PACKAGE__;
   }
 
+  $self->_default_response($config->{default_response}) if exists $config->{default_response};
+
   $self->{log_level} = $ENV{MOJO_OPENAPI_LOG_LEVEL} || $config->{log_level} || 'warn';
   $self->{renderer} = $config->{renderer} || \&_render_json;
   $self->_security_cb($config->{security}) if $config->{security};
@@ -81,6 +103,7 @@ sub _add_routes {
       my $to      = $op_spec->{'x-mojo-to'};
       my $endpoint;
 
+      $op_spec->{responses}{default} ||= $self->_default_response;
       $op_spec->{'x-all-parameters'} = [@path_parameters, @{$op_spec->{parameters} || []}];
       $has_options = 1 if lc $http_method eq 'options';
       $route_path = _route_path($path, $op_spec);
@@ -103,7 +126,8 @@ sub _add_routes {
     }
 
     unless ($has_options) {
-      $route->options($route_path => sub { _render_route_spec($_[0], $path) });
+      $route->options($route_path)
+        ->to('openapi.default_options' => 1, cb => sub { _render_route_spec($_[0], $path) },);
     }
   }
 }
@@ -273,7 +297,10 @@ sub _security_action {
 
   return sub {
     my $c = shift;
-    my @security_or = @{$c->openapi->spec->{security} || $global};
+    return 1 if $c->req->method eq 'OPTIONS' && $c->match->stack->[-1]{'openapi.default_options'};
+
+    my $spec = $c->openapi->spec || {};
+    my @security_or = @{$spec->{security} || $global};
     my %res;
 
     return 1 unless @security_or;    # Nothing to check
@@ -546,6 +573,34 @@ See L<JSON::Validator/coerce> for possible values that C<coerce> can take.
 
 Default: 1
 
+=item * default_response
+
+Used to set the "default" response schema, unless already specified in the
+spec. Set this argument to C<undef()> if you don't want the default to be
+added.
+
+Default value:
+
+  {
+    description => "Default response.",
+    schema      => {
+      type       => "object",
+      required   => ["errors"],
+      properties => {
+        errors => {
+          type  => "array",
+          items => {
+            type       => "object",
+            required   => ["message", "path"],
+            properties => {message => {"type" => "string"}, path => {"type" => "string"}}
+          }
+        }
+      }
+    }
+  }
+
+Note! The default "description" might change.
+
 =item * log_level
 
 C<log_level> is used when logging invalid request/response error messages.
@@ -828,7 +883,6 @@ __DATA__
 <body>
 <div class="container">
   %= include "mojolicious/plugin/openapi/header"
-  %= include "mojolicious/plugin/openapi/endpoint"
   %= include "mojolicious/plugin/openapi/resources"
   %= include "mojolicious/plugin/openapi/footer"
 </div>
